import {
  invigilateCount,
  invigilationWarningCount,
  reexamPendingCount,
  getLiveDomains,
} from "@/api/invigilation";

const state = {
  navTips: {
    RealtimeMonitoring: {
      val: "",
      classes: "nav-item-tips-popover",
    },
    WarningManage: {
      val: "",
      classes: "nav-item-tips-num",
    },
    ReexamPending: {
      val: "",
      classes: "nav-item-tips-num",
    },
  },
  cacheExamActivity: {
    examId: "",
    examActivityId: "",
  },
  detailIds: [],
  detailFilterData: {},
  detailFilterFunc: null,
  liveDomains: [],
  selectedExamId: null,
  warningMessageTimeCaches: {},
  warningMessageListTimeCaches: {},
};

const mutations = {
  setRealtimeMonitoring(state, val) {
    state.navTips.RealtimeMonitoring.val = val ? "考试" : null;
  },
  setWarningManage(state, val) {
    state.navTips.WarningManage.val = val;
  },
  setReexamPending(state, val) {
    state.navTips.ReexamPending.val = val;
  },
  setCacheExamActivity(state, cacheExamActivity) {
    state.cacheExamActivity = cacheExamActivity;
  },
  setDetailIds(state, detailIds) {
    state.detailIds = detailIds;
  },
  setDetailFilterData(state, detailFilterData) {
    state.detailFilterData = detailFilterData;
  },
  setDetailFilterFunc(state, detailFilterFunc) {
    state.detailFilterFunc = detailFilterFunc;
  },
  setLiveDomains(state, liveDomains) {
    state.liveDomains = liveDomains;
  },
  setSelectedExamId(state, selectedExamId) {
    state.selectedExamId = selectedExamId;
  },
  setWarningMessageTimeCaches(state, warningMessageTimeCaches) {
    state.warningMessageTimeCaches = warningMessageTimeCaches;
  },
  setWarningMessageListTimeCaches(state, warningMessageListTimeCaches) {
    state.warningMessageListTimeCaches = warningMessageListTimeCaches;
  },
};

const actions = {
  async fetchRealtimeMonitoringCount({ state, commit }, datas) {
    if (
      !state.cacheExamActivity.examId ||
      !state.cacheExamActivity.examActivityId
    )
      return;
    const res = await invigilateCount({ ...datas, ...state.cacheExamActivity });
    commit("setRealtimeMonitoring", res.data.data.length);
  },
  async fetchWarningManageCount({ state, commit }, datas) {
    if (
      !state.cacheExamActivity.examId ||
      !state.cacheExamActivity.examActivityId
    )
      return;
    const res = await invigilationWarningCount({
      ...datas,
      ...state.cacheExamActivity,
    });
    commit("setWarningManage", res.data.data.count);
  },
  async fetchReexamPendingCount({ state, commit }, datas) {
    if (
      !state.cacheExamActivity.examId ||
      !state.cacheExamActivity.examActivityId
    )
      return;
    const res = await reexamPendingCount({
      ...datas,
      ...state.cacheExamActivity,
    });
    commit("setReexamPending", res.data.data.count);
  },
  // 上一页，下一页 ------->
  resetDetailInfos({ state }) {
    state.detailIds = [];
    state.detailFilterData = {};
    state.detailFilterFunc = null;
  },
  async updateDetailInfos({ commit }, { filterData, fetchFunc, detailIds }) {
    commit("setDetailIds", [...new Set(detailIds)]);
    commit("setDetailFilterData", filterData);
    commit("setDetailFilterFunc", fetchFunc);
  },
  async fetchDetailIds({ state, commit }, pno) {
    const datas = { ...state.detailFilterData };
    datas.pageNumber += pno;
    if (datas.pageNumber === 0) return;
    if (datas.pageNumber > state.detailFilterData.pages) return;
    if (!state.detailFilterFunc) return;

    const res = await state.detailFilterFunc(datas);
    const ids = res.data.data.records.map((item) => item.examRecordId);
    commit("setDetailIds", [...new Set(ids)]);
    commit(
      "setDetailFilterData",
      Object.assign({}, state.detailFilterData, {
        pages: res.data.data.pages,
        pageNumber: res.data.data.current,
      })
    );
  },
  // 上一页，下一页 ------->
  async fetchLiveDomains({ commit }) {
    const res = await getLiveDomains();
    commit("setLiveDomains", res.data.data || []);
  },
  updateSelectedExamId(
    { commit },
    { exams, selectedExamId, defaultExamId = null }
  ) {
    if (!exams.length) return;
    const firstExamId = exams[0].id;
    const selectedExam = exams.find((item) => item.id === selectedExamId);
    const defaultExam = exams.find((item) => item.id === defaultExamId);
    const newSelectedExamId =
      (defaultExam && defaultExam.id) ||
      (selectedExam && selectedExam.id) ||
      firstExamId;
    commit("setSelectedExamId", newSelectedExamId);
  },
};

export default { namespaced: true, state, mutations, actions };
